==> icedtea-web_1.3.2.orig.tar.gz: icedtea-web-1.3.2/tests/reproducers/simple/AppletTakesLastParam/testcases/AppletTakesLastParamTests.java <==
/* AppletTestTests.java
Copyright (C) 2011 Red Hat, Inc.

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License as published by
the Free Software Foundation, version 2.

IcedTea is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
 */

import net.sourceforge.jnlp.ServerAccess;
import net.sourceforge.jnlp.ServerAccess.ProcessResult;
import net.sourceforge.jnlp.browsertesting.BrowserTest;
import net.sourceforge.jnlp.browsertesting.Browsers;
import net.sourceforge.jnlp.annotations.TestInBrowsers;
import org.junit.Assert;

import org.junit.Test;

public class AppletTakesLastParamTests extends BrowserTest {

    @Test
    public void AppletTest() throws Exception {
        ServerAccess.ProcessResult pr = server.executeJavaws(null, "/appletTakesLastParam.jnlp");
        evaluateApplet(pr);
    }

    private void evaluateApplet(ProcessResult pr) {
        String s0 = "value1";
        Assert.assertTrue("AppletTakesLastParam stdout should not contain " + s0 + " but did.", !pr.stdout.contains(s0));
        String s1 = "value2";
        Assert.assertTrue("AppletTakesLastParam stdout should contain " + s1 + " but did not.", pr.stdout.contains(s1));
    }

    @Test
    @TestInBrowsers(testIn = {Browsers.one})
    public void AppletInFirefoxTest() throws Exception {
        ServerAccess.ProcessResult pr = server.executeBrowser("/appletTakesLastParam.html");
        evaluateApplet(pr);
    }
}

==> icedtea-web-1.4.1.tar.gz: icedtea-web-1.4.1/tests/reproducers/simple/AppletTakesLastParam/testcases/AppletTakesLastParamTests.java <==
/* AppletTakesLastParamTests.java
Copyright (C) 2011 Red Hat, Inc.

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License as published by
the Free Software Foundation, version 2.

IcedTea is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
 */

import net.sourceforge.jnlp.ProcessResult;
import net.sourceforge.jnlp.ServerAccess.AutoClose;
import net.sourceforge.jnlp.browsertesting.BrowserTest;
import net.sourceforge.jnlp.browsertesting.Browsers;
import net.sourceforge.jnlp.annotations.TestInBrowsers;
import org.junit.Assert;

import org.junit.Test;

public class AppletTakesLastParamTests extends BrowserTest {
    private void evaluate(ProcessResult pr) {
        String firstParam = "value1";
        String secondParam = "value2";

        Assert.assertFalse("AppletTakesLastParam stdout should not contain " + firstParam + " but did.", 
                pr.stdout.contains(firstParam));
        Assert.assertTrue("AppletTakesLastParam stdout should contain " + secondParam + " but did not.", 
                pr.stdout.contains(secondParam));
    }

    @Test
    @TestInBrowsers(testIn = {Browsers.one})
    public void appletTakesLastParam() throws Exception {
        ProcessResult pr = server.executeBrowser("/appletTakesLastParam.html", AutoClose.CLOSE_ON_BOTH);
        evaluate(pr);
    }
    @Test
    public void jnlpTakesLastParam() throws Exception {
        ProcessResult pr = server.executeJavaws("/appletTakesLastParam.jnlp");
        evaluate(pr);
    }
}
